ApplyStrutStyleMacro class abstract

Implementers

Constructors

ApplyStrutStyleMacro()

Properties

applySturtStyle ← NikuStrutStyle
no getter
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
strutStyle ↔ NikuStrutStyle?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited
useSturtStyle(NikuStrutStyle v(NikuStrutStyle)) → void

Operators

operator ==(Object other) → bool
The equality operator.
inherited