BoxFitMacro class abstract

Implementers

Constructors

BoxFitMacro()

Properties

contain → void
no setter
cover → void
no setter
fill → void
no setter
fit ↔ BoxFit?
getter/setter pair
fitHeight → void
no setter
fitWidth → void
no setter
hashCode → int
The hash code for this object.
no setterinherited
noFit → void
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
scaleDown → void
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited