ButtonPaddingFullMacro class abstract

Implementers

Constructors

ButtonPaddingFullMacro()

Properties

buttonP ← double
no getter
buttonPadding ↔ NikuEdgeInsets?
getter/setter pair
buttonPb ← double
no getter
buttonPl ← double
no getter
buttonPr ← double
no getter
buttonPt ← double
no getter
buttonPx ← double
no getter
buttonPy ← double
no getter
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited