GapMacro class abstract

Implementers

Constructors

GapMacro()

Properties

children ↔ List<Widget>
getter/setter pair
gap ↔ double?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

$internalComposeGap(GapType type, double? size) → List<Widget>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited