MapTextStyleMacro class abstract

Implementers

Constructors

MapTextStyleMacro()

Properties

aboveline → void
no setter
background ← Paint
no getter
backgroundColor ← Color
no getter
bg ← Color
no getter
bodyLarge → void
no setter
bodyMedium → void
no setter
bodySmall → void
no setter
bold → void
no setter
color ← Color
no getter
dashed → void
no setter
debugLabel ← String
no getter
decoration ← TextDecoration
no getter
decorationColor ← Color
no getter
decorationStyle ← TextDecorationStyle
no getter
decorationThickness ← double
no getter
displayLarge → void
no setter
displayMedium → void
no setter
displaySmall → void
no setter
dotted → void
no setter
doubleLine → void
no setter
fontFamily ← String
no getter
fontFamilyFallback ← List<String>
no getter
fontFeatures ← List<FontFeature>
no getter
fontSize ← double
no getter
fontStyle ← FontStyle
no getter
fontWeight ← FontWeight
no getter
foreground ← Paint
no getter
hashCode → int
The hash code for this object.
no setterinherited
height ← double
no getter
italic → void
no setter
labelLarge → void
no setter
labelMedium → void
no setter
labelSmall → void
no setter
leadingDistribution ← TextLeadingDistribution
no getter
letterSpacing ← double
no getter
lineThrough → void
no setter
locale ← Locale
no getter
noDecoration → void
no setter
overflow ← TextOverflow
no getter
package ← String
no getter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
shadows ← List<Shadow>
no getter
solid → void
no setter
style ↔ NikuTextStyle?
getter/setter pair
textBaseline ← TextBaseline
no getter
titleLarge → void
no setter
titleMedium → void
no setter
titleSmall → void
no setter
underline → void
no setter
w100 → void
no setter
w200 → void
no setter
w300 → void
no setter
w400 → void
no setter
w500 → void
no setter
w600 → void
no setter
w700 → void
no setter
w800 → void
no setter
w900 → void
no setter
wavy → void
no setter
wordSpacing ← double
no getter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited