WidthHeightMacro class abstract

Implementers

Constructors

WidthHeightMacro()

Properties

h ← double
no getter
hashCode → int
The hash code for this object.
no setterinherited
height ↔ double?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
w ← double
no getter
width ↔ double?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited