NikuBoxConstraints class

Mixed-in types

Constructors

NikuBoxConstraints({double? minWidth, double? maxWidth, double? minHeight, double? maxHeight})

Properties

apply ← NikuBoxConstraints?
no getter
copied → NikuBoxConstraints
no setter
fullHeight → void
no setterinherited
fullSize → void
no setterinherited
fullWidth → void
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
maxHeight ↔ double?
getter/setter pairoverride
maxSize ← List<double>
no getterinherited
maxWidth ↔ double?
getter/setter pairoverride
minHeight ↔ double?
getter/setter pairoverride
minSize ← List<double>
no getterinherited
minWidth ↔ double?
getter/setter pairoverride
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
value → dynamic
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited