NikuEdgeInsets class

Constructors

NikuEdgeInsets({double? top, double? left, double? bottom, double? right})
NikuEdgeInsets.all(double value)
factory
NikuEdgeInsets.only({double? top, double? left, double? bottom, double? right})
factory
NikuEdgeInsets.symmetric({double? horizontal, double? vertical})
factory

Properties

apply ← NikuEdgeInsets?
no getter
bottom ↔ double?
getter/setter pair
copied → NikuEdgeInsets
no setter
hashCode → int
The hash code for this object.
no setterinherited
left ↔ double?
getter/setter pair
p ← double
no getter
pb ← double
no getter
pl ← double
no getter
pr ← double
no getter
pt ← double
no getter
px ← double
no getter
py ← double
no getter
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
top ↔ double?
getter/setter pair
value → EdgeInsets
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

zero → const EdgeInsets