NikuStrutStyle class

Mixed-in types

Constructors

NikuStrutStyle({String? fontFamily, List<String>? fontFamilyFallback, double? fontSize, double? height, TextLeadingDistribution? leadingDistribution, double? leading, FontWeight? fontWeight, FontStyle? fontStyle, bool? forceStrutHeight, String? debugLabel, String? package})

Properties

apply ← NikuStrutStyle?
no getter
bold → void
no setterinherited
copied → NikuStrutStyle
no setter
debugLabel ↔ String?
getter/setter pair
fontFamily ↔ String?
getter/setter pair
fontFamilyFallback ↔ List<String>?
getter/setter pair
fontSize ↔ double?
getter/setter pair
fontStyle ↔ FontStyle?
getter/setter pairoverride
fontWeight ↔ FontWeight?
getter/setter pairoverride
forceStrutHeight ↔ bool?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
height ↔ double?
getter/setter pair
italic → void
no setterinherited
leading ↔ double?
getter/setter pair
leadingDistribution ↔ TextLeadingDistribution?
getter/setter pair
package ↔ String?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
value → StrutStyle
no setter
w100 → void
no setterinherited
w200 → void
no setterinherited
w300 → void
no setterinherited
w400 → void
no setterinherited
w500 → void
no setterinherited
w600 → void
no setterinherited
w700 → void
no setterinherited
w800 → void
no setterinherited
w900 → void
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited