NikuTextStyle class

Mixed-in types

Constructors

NikuTextStyle({bool inherit = true, Color? color, Color? backgroundColor, String? fontFamily, List<String>? fontFamilyFallback, double? fontSize, FontWeight? fontWeight, FontStyle? fontStyle, double? letterSpacing, double? wordSpacing, TextBaseline? textBaseline, double? height, TextLeadingDistribution? leadingDistribution, Locale? locale, Paint? foreground, Paint? background, TextDecoration? decoration, Color? decorationColor, TextDecorationStyle? decorationStyle, double? decorationThickness, String? debugLabel, List<Shadow>? shadows, List<FontFeature>? fontFeatures, TextOverflow? overflow, String? package, double? leading, bool? forceStrutHeight})

Properties

aboveline → void
no setterinherited
apply ← NikuTextStyle?
no getter
background ↔ Paint?
getter/setter pair
backgroundColor ↔ Color?
getter/setter pairoverride
bg ← Color
no getterinherited
bodyLarge → void
no setterinherited
bodyMedium → void
no setterinherited
bodySmall → void
no setterinherited
bold → void
no setterinherited
color ↔ Color?
getter/setter pair
copied → NikuTextStyle
no setter
dashed → void
no setterinherited
debugLabel ↔ String?
getter/setter pair
decoration ↔ TextDecoration?
getter/setter pairoverride
decorationColor ↔ Color?
getter/setter pair
decorationStyle ↔ TextDecorationStyle?
getter/setter pairoverride
decorationThickness ↔ double?
getter/setter pair
displayLarge → void
no setterinherited
displayMedium → void
no setterinherited
displaySmall → void
no setterinherited
dotted → void
no setterinherited
double → void
no setterinherited
fontFamily ↔ String?
getter/setter pair
fontFamilyFallback ↔ List<String>?
getter/setter pair
fontFeatures ↔ List<FontFeature>?
getter/setter pair
fontSize ↔ double?
getter/setter pair
fontStyle ↔ FontStyle?
getter/setter pairoverride
fontWeight ↔ FontWeight?
getter/setter pairoverride
foreground ↔ Paint?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
height ↔ double?
getter/setter pair
inherit ↔ bool
getter/setter pair
italic → void
no setterinherited
labelLarge → void
no setterinherited
labelMedium → void
no setterinherited
labelSmall → void
no setterinherited
leadingDistribution ↔ TextLeadingDistribution?
getter/setter pair
letterSpacing ↔ double?
getter/setter pair
lineThrough → void
no setterinherited
locale ↔ Locale?
getter/setter pair
noDecoration → void
no setterinherited
overflow ↔ TextOverflow?
getter/setter pair
package ↔ String?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
shadows ↔ List<Shadow>?
getter/setter pair
solid → void
no setterinherited
textBaseline ↔ TextBaseline?
getter/setter pair
themeBuilder ↔ TextStyle? Function(BuildContext)?
getter/setter pairoverride
titleLarge → void
no setterinherited
titleMedium → void
no setterinherited
titleSmall → void
no setterinherited
underline → void
no setterinherited
value → TextStyle
no setter
w100 → void
no setterinherited
w200 → void
no setterinherited
w300 → void
no setterinherited
w400 → void
no setterinherited
w500 → void
no setterinherited
w600 → void
no setterinherited
w700 → void
no setterinherited
w800 → void
no setterinherited
w900 → void
no setterinherited
wavy → void
no setterinherited
wordSpacing ↔ double?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited