ButtonStyleTextStyleProxy class abstract

Implementers

Constructors

ButtonStyleTextStyleProxy()

Properties

aboveline → void
no setter
background ← Paint?
no getter
backgroundColor ← Color?
no getter
bodyLarge → dynamic
no setter
bodyMedium → dynamic
no setter
bodySmall → dynamic
no setter
bold → void
no setter
color ← Color?
no getter
dashed → void
no setter
debugLabel ← String?
no getter
decoration ← TextDecoration?
no getter
decorationColor ← Color?
no getter
decorationStyle ← TextDecorationStyle?
no getter
decorationThickness ← double?
no getter
displayLarge → dynamic
no setter
displayMedium → dynamic
no setter
displaySmall → dynamic
no setter
dotted → void
no setter
fontFamily ← String?
no getter
fontFamilyFallback ← List<String>?
no getter
fontFeatures ← List<FontFeature>?
no getter
fontSize ← double?
no getter
fontStyle ← FontStyle?
no getter
fontWeight ← FontWeight?
no getter
foreground ← Paint?
no getter
hashCode → int
The hash code for this object.
no setterinherited
height ← double?
no getter
inherit ← bool
no getter
italic → void
no setter
labelLarge → dynamic
no setter
labelMedium → dynamic
no setter
labelSmall → dynamic
no setter
leadingDistribution ← TextLeadingDistribution?
no getter
letterSpacing ← double?
no getter
lineThrough → void
no setter
locale ← Locale?
no getter
noDecoration → void
no setter
overflow ← TextOverflow?
no getter
package ← String?
no getter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
shadows ← List<Shadow>?
no getter
solid → void
no setter
style ↔ NikuButtonStyle?
getter/setter pair
textBaseline ← TextBaseline?
no getter
titleLarge → dynamic
no setter
titleMedium → dynamic
no setter
titleSmall → dynamic
no setter
underline → void
no setter
w100 → void
no setter
w200 → void
no setter
w300 → void
no setter
w400 → void
no setter
w500 → void
no setter
w600 → void
no setter
w700 → void
no setter
w800 → void
no setter
w900 → void
no setter
wavy → void
no setter
wordSpacing ← double?
no getter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited