InputDecorationProxy class abstract

Implementers

Constructors

InputDecorationProxy()

Properties

alignLabelWithHint ← bool?
no getter
alwaysFloat → void
no setter
applyConstraints ← NikuBoxConstraints
no getter
applyErrorStyle ← NikuTextStyle
no getter
applyFloatingLabelStyle ← NikuTextStyle
no getter
applyHelperStyle ← NikuTextStyle
no getter
applyHintStyle ← NikuTextStyle
no getter
applyLabelStyle ← NikuTextStyle
no getter
applyPrefixIconConstraints ← NikuBoxConstraints
no getter
applyPrefixStyle ← NikuTextStyle
no getter
applySuffixIconConstraints ← NikuBoxConstraints
no getter
applySuffixStyle ← NikuTextStyle
no getter
autoFloat → void
no setter
baseBorderColor ← Color
no getter
baseBorderWidth ← double
no getter
bg ← Color
no getter
border ← NikuInputBorder?
no getter
borderColor ← Color
no getter
borderWidth ← double
no getter
constraints ← NikuBoxConstraints?
no getter
contentPadding ← NikuEdgeInsets?
no getter
counter ← Widget?
no getter
counterStyle ← NikuTextStyle?
no getter
counterText ← String?
no getter
decoration ↔ NikuInputDecoration?
getter/setter pair
disabledBorder ← NikuInputBorder?
no getter
disabledBorderColor ← Color
no getter
disabledBorderWidth ← double
no getter
enabled ← bool?
no getter
enabledBorder ← NikuInputBorder?
no getter
enabledBorderColor ← Color
no getter
enabledBorderWidth ← double
no getter
errorBorder ← NikuInputBorder?
no getter
errorBorderColor ← Color
no getter
errorBorderWidth ← double
no getter
errorMaxLines ← int?
no getter
errorStyle ← NikuTextStyle?
no getter
errorText ← String?
no getter
fillColor ← Color?
no getter
filled ← bool?
no getter
floatingLabel ← FloatingLabelBehavior
no getter
floatingLabelBehavior ← FloatingLabelBehavior?
no getter
floatingLabelStyle ← NikuTextStyle?
no getter
focusColor ← Color?
no getter
focusedBorder ← NikuInputBorder?
no getter
focusedBorderColor ← Color
no getter
focusedBorderWidth ← double
no getter
focusedErrorBorder ← NikuInputBorder?
no getter
focusedErrorBorderColor ← Color
no getter
focusedErrororderWidth ← double
no getter
fullHeight → void
no setter
fullSize → void
no setter
fullWidth → void
no setter
hashCode → int
The hash code for this object.
no setterinherited
helperMaxLines ← int?
no getter
helperStyle ← NikuTextStyle?
no getter
helperText ← String?
no getter
hintMaxLines ← int?
no getter
hintStyle ← NikuTextStyle?
no getter
hintText ← String?
no getter
hintTextDirection ← TextDirection?
no getter
hoverColor ← Color?
no getter
icon ← Widget?
no getter
isCollapsed ← bool?
no getter
isDense ← bool?
no getter
isFilled → void
no setter
label ← Widget?
no getter
labelStyle ← NikuTextStyle?
no getter
labelText ← String?
no getter
maxSize ← List<double>
no getter
minSize ← List<double>
no getter
neverFloat → void
no setter
noUnderline → void
no setter
outlined → void
no setter
p ← double
no getter
pb ← double
no getter
pl ← double
no getter
pr ← double
no getter
prefix ← Widget?
no getter
prefixIcon ← Widget?
no getter
prefixIconConstraints ← NikuBoxConstraints?
no getter
prefixStyle ← NikuTextStyle?
no getter
prefixText ← String?
no getter
pt ← double
no getter
px ← double
no getter
py ← double
no getter
rounded ↔ double
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
semanticCounterText ← String?
no getter
suffix ← Widget?
no getter
suffixIcon ← Widget?
no getter
suffixIconConstraints ← NikuBoxConstraints?
no getter
suffixStyle ← NikuTextStyle?
no getter
suffixText ← String?
no getter
underline → void
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited
useBorder({InputBorder? all, InputBorder? base, InputBorder? enabled, InputBorder? disabled, InputBorder? focused, InputBorder? focusedError, InputBorder? error}) → void
useBorderColor({Color? all, Color? base, Color? enabled, Color? disabled, Color? focused, Color? focusedError, Color? error}) → void
useBorderWidth({double? all, double? base, double? enabled, double? disabled, double? focused, double? focusedError, double? error}) → void
useConstraints(_UseConstraints v) → void
useErrorStyle(_UseStyle v) → void
useFloatingLabelStyle(_UseStyle v) → void
useHelperStyle(_UseStyle v) → void
useHintStyle(_UseStyle v) → void
useLabelStyle(_UseStyle v) → void
useNikuBorder({NikuInputBorder? all, NikuInputBorder? base, NikuInputBorder? enabled, NikuInputBorder? disabled, NikuInputBorder? focused, NikuInputBorder? focusedError, NikuInputBorder? error}) → void
usePrefixIconConstraints(_UseConstraints v) → void
usePrefixStyle(_UseStyle v) → void
useSuffixIconConstraints(_UseConstraints v) → void
useSuffixStyle(_UseStyle v) → void

Operators

operator ==(Object other) → bool
The equality operator.
inherited