NikuButton class

Inheritance
Mixed-in types
Available extensions

Constructors

NikuButton(Widget child, {Key? key, NikuButtonType? type, VoidCallback? onPressed, VoidCallback? onLongPress, NikuButtonStyle? style, FocusNode? focusNode, Clip? clipBehavior, bool? autofocus, Widget? icon, Widget? label, bool enable = true})
NikuButton.elevated(Widget child, {Key? key, VoidCallback? onPressed, VoidCallback? onLongPress, NikuButtonStyle? style, FocusNode? focusNode, bool? autofocus, Clip? clipBehavior, bool enable = true})
factory
NikuButton.elevatedIcon(Widget label, Widget icon, {Key? key, VoidCallback? onPressed, VoidCallback? onLongPress, NikuButtonStyle? style, FocusNode? focusNode, bool? autofocus, Clip? clipBehavior, bool enable = true})
factory
NikuButton.filled(Widget child, {Key? key, VoidCallback? onPressed, VoidCallback? onLongPress, NikuButtonStyle? style, FocusNode? focusNode, bool? autofocus, Clip? clipBehavior, bool enable = true})
factory
NikuButton.filledIcon(Widget label, Widget icon, {Key? key, VoidCallback? onPressed, VoidCallback? onLongPress, NikuButtonStyle? style, FocusNode? focusNode, bool? autofocus, Clip? clipBehavior, bool enable = true})
factory
NikuButton.icon(Widget label, Widget icon, {Key? key, VoidCallback? onPressed, VoidCallback? onLongPress, NikuButtonStyle? style, FocusNode? focusNode, bool? autofocus, Clip? clipBehavior, bool enable = true})
factory
NikuButton.outlined(Widget child, {Key? key, VoidCallback? onPressed, VoidCallback? onLongPress, NikuButtonStyle? style, FocusNode? focusNode, bool? autofocus, Clip? clipBehavior, bool enable = true})
factory
NikuButton.outlinedIcon(Widget label, Widget icon, {Key? key, VoidCallback? onPressed, VoidCallback? onLongPress, NikuButtonStyle? style, FocusNode? focusNode, bool? autofocus, Clip? clipBehavior, bool enable = true})
factory
NikuButton.tonal(Widget child, {Key? key, VoidCallback? onPressed, VoidCallback? onLongPress, NikuButtonStyle? style, FocusNode? focusNode, bool? autofocus, Clip? clipBehavior, bool enable = true})
factory
NikuButton.tonalIcon(Widget label, Widget icon, {Key? key, VoidCallback? onPressed, VoidCallback? onLongPress, NikuButtonStyle? style, FocusNode? focusNode, bool? autofocus, Clip? clipBehavior, bool enable = true})
factory

Properties

$parent → Niku
finalinherited
aboveline → void
no setterinherited
alignment ← AlignmentGeometry?

Available on NikuButton, provided by the ButtonStyleProxy extension

no getter
animationDuration ← Duration?

Available on NikuButton, provided by the ButtonStyleProxy extension

no getter
antiAlias → void
no setterinherited
antiAliasWithSaveLayer → void
no setterinherited
apply ← NikuButton?
no getteroverride
applyButtonStyle ← NikuButtonStyle
no getterinherited
aspect ← double
no getterinherited
aspectRatio ← double
no getterinherited
autofocus ↔ bool?
getter/setter pair
background ← Paint?
no getterinherited
backgroundColor ← Color

Available on NikuButton, provided by the ButtonStyleProxy extension

no getter
backgroundColor ← Color?
no getterinherited
backgroundColorState ← NikuState<Color?>?

Available on NikuButton, provided by the ButtonStyleProxy extension

no getter
bg ← Color

Available on NikuButton, provided by the ButtonStyleProxy extension

no getter
bodyLarge → dynamic
no setterinherited
bodyMedium → dynamic
no setterinherited
bodySmall → dynamic
no setterinherited
bold → void
no setterinherited
border ← BorderSide

Available on NikuButton, provided by the ButtonStyleProxy extension

no getter
bottomCenter → void

Available on NikuButton, provided by the ButtonStyleProxy extension

no setter
bottomEnd → void

Available on NikuButton, provided by the ButtonStyleProxy extension

no setter
bottomStart → void

Available on NikuButton, provided by the ButtonStyleProxy extension

no setter
boxConstraints ← BoxConstraints
no getterinherited
center → void

Available on NikuButton, provided by the ButtonStyleProxy extension

no setter
centerEnd → void

Available on NikuButton, provided by the ButtonStyleProxy extension

no setter
centerStart → void

Available on NikuButton, provided by the ButtonStyleProxy extension

no setter
child ↔ Widget
getter/setter pair
clip ↔ Clip?
getter/setter pairinherited
clipBehavior ↔ Clip?
getter/setter pair
color ← Color?
no getterinherited
copied → NikuButton
no setteroverride
dashed → void
no setterinherited
debugLabel ← String?
no getterinherited
decoration ← TextDecoration?
no getterinherited
decorationColor ← Color?
no getterinherited
decorationStyle ← TextDecorationStyle?
no getterinherited
decorationThickness ← double?
no getterinherited
deps ↔ List
getter/setter pairinherited
displayLarge → dynamic
no setterinherited
displayMedium → dynamic
no setterinherited
displaySmall → dynamic
no setterinherited
dotted → void
no setterinherited
elevation ← double

Available on NikuButton, provided by the ButtonStyleProxy extension

no getter
elevationState ← NikuState<double?>?

Available on NikuButton, provided by the ButtonStyleProxy extension

no getter
enable ↔ bool
getter/setter pair
enableFeedback ← bool?

Available on NikuButton, provided by the ButtonStyleProxy extension

no getter
expanded → dynamic
no setterinherited
fg ← Color

Available on NikuButton, provided by the ButtonStyleProxy extension

no getter
fh ← double
no getterinherited
fill → void
no setterinherited
fixedSizeState ← NikuState<Size?>?

Available on NikuButton, provided by the ButtonStyleProxy extension

no getter
flex ↔ int
getter/setter pairinherited
focusNode ↔ FocusNode?
getter/setter pairoverride
fontFamily ← String?
no getterinherited
fontFamilyFallback ← List<String>?
no getterinherited
fontFeatures ← List<FontFeature>?
no getterinherited
fontSize ← double?
no getterinherited
fontStyle ← FontStyle?
no getterinherited
fontWeight ← FontWeight?
no getterinherited
foreground ← Paint?
no getterinherited
foregroundColor ← Color

Available on NikuButton, provided by the ButtonStyleProxy extension

no getter
foregroundColorState ← NikuState<Color?>?

Available on NikuButton, provided by the ButtonStyleProxy extension

no getter
formKey ← Key
no getterinherited
fractionH ← double
no getterinherited
fractionHeight ← double
no getterinherited
fractionSize ← List<double>
no getterinherited
fractionW ← double
no getterinherited
fractionWidth ← double
no getterinherited
freezed → void
no setterinherited
fullHeight → void
no setterinherited
fullSize → void
no setterinherited
fullWidth → void
no setterinherited
fw ← double
no getterinherited
h ← double
no getterinherited
h100 → void
no setterinherited
hardEdge → void
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
height ← double?
no getterinherited
heightPercent ← double
no getterinherited
hFactor ← double
no getterinherited
hFull → void
no setterinherited
hidden → dynamic
no setterinherited
hMax ← double
no getterinherited
hMin ← double
no getterinherited
hPercent ← double
no getterinherited
icon ↔ Widget?
getter/setter pair
inherit ← bool
no getterinherited
italic → void
no setterinherited
key → Key?
Controls how one widget replaces another widget in the tree.
finalinherited
label ↔ Widget?
getter/setter pair
labelLarge → dynamic
no setterinherited
labelMedium → dynamic
no setterinherited
labelSmall → dynamic
no setterinherited
leadingDistribution ← TextLeadingDistribution?
no getterinherited
letterSpacing ← double?
no getterinherited
lineThrough → void
no setterinherited
locale ← Locale?
no getterinherited
m ← double
no getterinherited
margin ← EdgeInsets
no getterinherited
maxH ← double
no getterinherited
maxHeight ← double
no getterinherited
maximumSize ← Size

Available on NikuButton, provided by the ButtonStyleProxy extension

no getter
maximumSizeState ← NikuState<Size?>?

Available on NikuButton, provided by the ButtonStyleProxy extension

no getter
maxSize ← Size

Available on NikuButton, provided by the ButtonStyleProxy extension

no getter
maxSize ← List<double>
no getterinherited
maxW ← double
no getterinherited
maxWidth ← double
no getterinherited
mb ← double
no getterinherited
minH ← double
no getterinherited
minHeight ← double
no getterinherited
minimumSize ← Size

Available on NikuButton, provided by the ButtonStyleProxy extension

no getter
minimumSizeState ← NikuState<Size?>?

Available on NikuButton, provided by the ButtonStyleProxy extension

no getter
minSize ← Size

Available on NikuButton, provided by the ButtonStyleProxy extension

no getter
minSize ← List<double>
no getterinherited
minW ← double
no getterinherited
minWidth ← double
no getterinherited
ml ← double
no getterinherited
mouseCursor ← MouseCursor

Available on NikuButton, provided by the ButtonStyleProxy extension

no getter
mouseCursorState ← NikuState<MouseCursor?>?

Available on NikuButton, provided by the ButtonStyleProxy extension

no getter
mr ← double
no getterinherited
mt ← double
no getterinherited
mx ← double
no getterinherited
my ← double
no getterinherited
n → NikuExplictParentBuilder
no setterinherited
niku → Niku

Available on Widget, provided by the NikuTransform extension

no setter
noClip → void
no setterinherited
noDecoration → void
no setterinherited
onLongPress ↔ VoidCallback?
getter/setter pair
onPressed ↔ VoidCallback?
getter/setter pair
overflow ← TextOverflow?
no getterinherited
overlay ← Color

Available on NikuButton, provided by the ButtonStyleProxy extension

no getter
overlayColor ← Color

Available on NikuButton, provided by the ButtonStyleProxy extension

no getter
overlayColorState ← NikuState<Color?>?

Available on NikuButton, provided by the ButtonStyleProxy extension

no getter
p ← double

Available on NikuButton, provided by the ButtonStyleProxy extension

no getter
package ← String?
no getterinherited
padding ← EdgeInsets

Available on NikuButton, provided by the ButtonStyleProxy extension

no getter
paddingState ← NikuState<EdgeInsets?>?

Available on NikuButton, provided by the ButtonStyleProxy extension

no getter
parent → NikuExplictParentBuilder
no setterinherited
pb ← double

Available on NikuButton, provided by the ButtonStyleProxy extension

no getter
pl ← double

Available on NikuButton, provided by the ButtonStyleProxy extension

no getter
pr ← double

Available on NikuButton, provided by the ButtonStyleProxy extension

no getter
pt ← double

Available on NikuButton, provided by the ButtonStyleProxy extension

no getter
px ← double

Available on NikuButton, provided by the ButtonStyleProxy extension

no getter
py ← double

Available on NikuButton, provided by the ButtonStyleProxy extension

no getter
ratio ← double
no getterinherited
rounded ↔ double

Available on NikuButton, provided by the ButtonStyleProxy extension

getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
scrollable → void
no setterinherited
self → NikuButton
no setteroverride
shadowColor ← Color

Available on NikuButton, provided by the ButtonStyleProxy extension

no getter
shadowColorState ← NikuState<Color?>?

Available on NikuButton, provided by the ButtonStyleProxy extension

no getter
shadows ← List<Shadow>?
no getterinherited
shape ← OutlinedBorder

Available on NikuButton, provided by the ButtonStyleProxy extension

no getter
shapeState ← NikuState<OutlinedBorder?>?

Available on NikuButton, provided by the ButtonStyleProxy extension

no getter
sideState ← NikuState<BorderSide?>?

Available on NikuButton, provided by the ButtonStyleProxy extension

no getter
sizePercent ← List<double>
no getterinherited
sliverToBox → void
no setterinherited
solid → void
no setterinherited
splash ← Color

Available on NikuButton, provided by the ButtonStyleProxy extension

no getter
splashFactory ← InteractiveInkFeatureFactory?

Available on NikuButton, provided by the ButtonStyleProxy extension

no getter
style ↔ NikuButtonStyle?
getter/setter pairoverride
tapTargetSize ← MaterialTapTargetSize?

Available on NikuButton, provided by the ButtonStyleProxy extension

no getter
textBaseline ← TextBaseline?
no getterinherited
textStyleState ← NikuState<NikuTextStyle?>?

Available on NikuButton, provided by the ButtonStyleProxy extension

no getter
theme ← ThemeData
no getterinherited
tip ← String
no getterinherited
titleLarge → dynamic
no setterinherited
titleMedium → dynamic
no setterinherited
titleSmall → dynamic
no setterinherited
tooltip ← String
no getterinherited
topCenter → void

Available on NikuButton, provided by the ButtonStyleProxy extension

no setter
topEnd → void

Available on NikuButton, provided by the ButtonStyleProxy extension

no setter
topStart → void

Available on NikuButton, provided by the ButtonStyleProxy extension

no setter
type ↔ NikuButtonType?
getter/setter pair
underline → void
no setterinherited
visible ← bool
no getterinherited
visualDensity ← VisualDensity?

Available on NikuButton, provided by the ButtonStyleProxy extension

no getter
w ← double
no getterinherited
w100 → void
no setterinherited
w200 → void
no setterinherited
w300 → void
no setterinherited
w400 → void
no setterinherited
w500 → void
no setterinherited
w600 → void
no setterinherited
w700 → void
no setterinherited
w800 → void
no setterinherited
w900 → void
no setterinherited
wavy → void
no setterinherited
wFactor ← double
no getterinherited
wFull → void
no setterinherited
width ← double
no getterinherited
widthPercent ← double
no getterinherited
wMax ← double
no getterinherited
wMin ← double
no getterinherited
wordSpacing ← double?
no getterinherited
wPercent ← double
no getterinherited
wrap → dynamic
Cancel parent size inheritance by wrapping the widget with a Wrap.
no setterinherited

Methods

applyTextStyle(NikuTextStyle v) → void
build(BuildContext _) → Widget
inherited
createElement() → StatelessElement
Creates a StatelessElement to manage this widget's location in the tree.
inherited
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
of(NikuButton? v) → void
inherited
on({void tapDown(TapDownDetails)?, void tapUp(TapUpDetails)?, VoidCallback? tap, VoidCallback? tapCancel, VoidCallback? secondaryTap, void secondaryTapDown(TapDownDetails)?, void secondaryTapUp(TapUpDetails)?, VoidCallback? secondaryTapCancel, void tertiaryTapDown(TapDownDetails)?, void tertiaryTapUp(TapUpDetails)?, VoidCallback? tertiaryTapCancel, void doubleTapDown(TapDownDetails)?, VoidCallback? doubleTap, VoidCallback? doubleTapCancel, VoidCallback? longPress, void longPressStart(LongPressStartDetails)?, void longPressMoveUpdate(LongPressMoveUpdateDetails)?, VoidCallback? longPressUp, void longPressEnd(LongPressEndDetails)?, VoidCallback? secondaryLongPress, void secondaryLongPressStart(LongPressStartDetails)?, void secondaryLongPressMoveUpdate(LongPressMoveUpdateDetails)?, VoidCallback? secondaryLongPressUp, void secondaryLongPressEnd(LongPressEndDetails)?, void verticalDragDown(DragDownDetails)?, void verticalDragStart(DragStartDetails)?, void verticalDragUpdate(DragUpdateDetails)?, void verticalDragEnd(DragEndDetails)?, VoidCallback? verticalDragCancel, void horizontalDragDown(DragDownDetails)?, void horizontalDragStart(DragStartDetails)?, void horizontalDragUpdate(DragUpdateDetails)?, void horizontalDragEnd(DragEndDetails)?, VoidCallback? horizontalDragCancel, void forcePressStart(ForcePressDetails)?, void forcePressPeak(ForcePressDetails)?, void forcePressUpdate(ForcePressDetails)?, void forcePressEnd(ForcePressDetails)?, void panDown(DragDownDetails)?, void panStart(DragStartDetails)?, void panUpdate(DragUpdateDetails)?, void panEnd(DragEndDetails)?, VoidCallback? panCancel, void scaleStart(ScaleStartDetails)?, void scaleUpdate(ScaleUpdateDetails)?, void scaleEnd(ScaleEndDetails)?}) → void
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A short, textual description of this widget.
inherited
use(List<NikuButton> v) → void
inherited
useAnimationBuilder({required Widget builder(BuildContext context, Widget child), required AnimationController animation}) → void
inherited
useBg({Color? base, Color? disabled, Color? dragged, Color? error, Color? focused, Color? hovered, Color? pressed, Color? scrolledUnder, Color? selected}) → void

Available on NikuButton, provided by the ButtonStyleProxy extension

useButtonStyle(NikuButtonStyle v(NikuButtonStyle)) → void
inherited
useColor({Color? base, Color? disabled, Color? dragged, Color? error, Color? focused, Color? hovered, Color? pressed, Color? scrolledUnder, Color? selected}) → void

Available on NikuButton, provided by the ButtonStyleProxy extension

useCursor({MouseCursor? base, MouseCursor? disabled, MouseCursor? dragged, MouseCursor? error, MouseCursor? focused, MouseCursor? hovered, MouseCursor? pressed, MouseCursor? scrolledUnder, MouseCursor? selected}) → void

Available on NikuButton, provided by the ButtonStyleProxy extension

useDarkMode(BuildContext context, NikuButton builder(NikuButton, bool)) → void
inherited
useElevation({double? base, double? disabled, double? dragged, double? error, double? focused, double? hovered, double? pressed, double? scrolledUnder, double? selected}) → void

Available on NikuButton, provided by the ButtonStyleProxy extension

useFg({Color? base, Color? disabled, Color? dragged, Color? error, Color? focused, Color? hovered, Color? pressed, Color? scrolledUnder, Color? selected}) → void

Available on NikuButton, provided by the ButtonStyleProxy extension

useFocus(FocusNode builder(FocusNode?), {String? debugLabel, FocusOnKeyCallback? onKey, FocusOnKeyEventCallback? onKeyEvent, bool skipTraversal = false, bool canRequestFocus = true, bool descendantsAreFocusable = true}) → dynamic
inherited
useFocusNode(FocusNode builder(FocusNode?), {String? debugLabel, FocusOnKeyCallback? onKey, FocusOnKeyEventCallback? onKeyEvent, bool skipTraversal = false, bool canRequestFocus = true, bool descendantsAreFocusable = true}) → dynamic
inherited
useForm({Key? key, AutovalidateMode? autovalidateMode, Future<bool> onWillPop()?, void onChanged()?}) → void
inherited
useMaximumSize({Size? base, Size? disabled, Size? dragged, Size? error, Size? focused, Size? hovered, Size? pressed, Size? scrolledUnder, Size? selected}) → void

Available on NikuButton, provided by the ButtonStyleProxy extension

useMaxSize({Size? base, Size? disabled, Size? dragged, Size? error, Size? focused, Size? hovered, Size? pressed, Size? scrolledUnder, Size? selected}) → void

Available on NikuButton, provided by the ButtonStyleProxy extension

useMinimumSize({Size? base, Size? disabled, Size? dragged, Size? error, Size? focused, Size? hovered, Size? pressed, Size? scrolledUnder, Size? selected}) → void

Available on NikuButton, provided by the ButtonStyleProxy extension

useMinSize({Size? base, Size? disabled, Size? dragged, Size? error, Size? focused, Size? hovered, Size? pressed, Size? scrolledUnder, Size? selected}) → void

Available on NikuButton, provided by the ButtonStyleProxy extension

useNikuTextStyle(NikuTextStyle v(NikuTextStyle)) → void

Available on NikuButton, provided by the ButtonStyleProxy extension

useOverlayColor({Color? base, Color? disabled, Color? dragged, Color? error, Color? focused, Color? hovered, Color? pressed, Color? scrolledUnder, Color? selected}) → void

Available on NikuButton, provided by the ButtonStyleProxy extension

useP({double? base, double? disabled, double? dragged, double? error, double? focused, double? hovered, double? pressed, double? scrolledUnder, double? selected}) → void

Available on NikuButton, provided by the ButtonStyleProxy extension

usePadding({EdgeInsets? base, EdgeInsets? disabled, EdgeInsets? dragged, EdgeInsets? error, EdgeInsets? focused, EdgeInsets? hovered, EdgeInsets? pressed, EdgeInsets? scrolledUnder, EdgeInsets? selected}) → void

Available on NikuButton, provided by the ButtonStyleProxy extension

useParent(Widget compose(Niku)) → void
inherited
usePlatform(BuildContext context, {NikuButton android(NikuButton)?, NikuButton iOS(NikuButton)?, NikuButton fuchsia(NikuButton)?, NikuButton linux(NikuButton)?, NikuButton macOS(NikuButton)?, NikuButton windows(NikuButton)?, NikuButton web(NikuButton)?}) → void
inherited
useQuery(BuildContext context, NikuButton builder(NikuButton, MediaQueryData)) → void
inherited
useRounded({double base = 0, double? disabled, double? dragged, double? error, double? focused, double? hovered, double? pressed, double? scrolledUnder, double? selected}) → void

Available on NikuButton, provided by the ButtonStyleProxy extension

useScreen(BuildContext context, {NikuButton base(NikuButton)?, NikuButton xs(NikuButton)?, NikuButton sm(NikuButton)?, NikuButton md(NikuButton)?, NikuButton lg(NikuButton)?, NikuButton xl(NikuButton)?}) → void
void useScreen({ // > 568px Widget Function(Niku)? base, // 568 - 640px Widget Function(Niku)? xs, // 640 - 768px Widget Function(Niku)? sm, // 768 - 920px Widget Function(Niku)? md, // 920 - 1024px Widget Function(Niku)? lg, // > 1024px Widget Function(Niku)? xl, })
inherited
useScrollView({ScrollController? controller, Axis scrollDirection = Axis.vertical, bool? primary, bool reverse = false, ScrollPhysics? physics, DragStartBehavior dragStartBehavior = DragStartBehavior.start, String? restorationId}) → void
inherited
useShadowColor({Color? base, Color? disabled, Color? dragged, Color? error, Color? focused, Color? hovered, Color? pressed, Color? scrolledUnder, Color? selected}) → void

Available on NikuButton, provided by the ButtonStyleProxy extension

useShape({OutlinedBorder? base, OutlinedBorder? disabled, OutlinedBorder? dragged, OutlinedBorder? error, OutlinedBorder? focused, OutlinedBorder? hovered, OutlinedBorder? pressed, OutlinedBorder? scrolledUnder, OutlinedBorder? selected}) → void

Available on NikuButton, provided by the ButtonStyleProxy extension

useSide({BorderSide? base, BorderSide? disabled, BorderSide? dragged, BorderSide? error, BorderSide? focused, BorderSide? hovered, BorderSide? pressed, BorderSide? scrolledUnder, BorderSide? selected}) → void

Available on NikuButton, provided by the ButtonStyleProxy extension

useSize(BuildContext context, NikuButton builder(NikuButton, Size)) → void
inherited
useSplash({Color? base, Color? disabled, Color? dragged, Color? error, Color? focused, Color? hovered, Color? pressed, Color? scrolledUnder, Color? selected}) → void

Available on NikuButton, provided by the ButtonStyleProxy extension

useTextStyle(NikuTextStyle cb(NikuTextStyle)) → void
useTextStyle({NikuTextStyle base(NikuTextStyle)?, NikuTextStyle disabled(NikuTextStyle)?, NikuTextStyle dragged(NikuTextStyle)?, NikuTextStyle error(NikuTextStyle)?, NikuTextStyle focused(NikuTextStyle)?, NikuTextStyle hovered(NikuTextStyle)?, NikuTextStyle pressed(NikuTextStyle)?, NikuTextStyle scrolledUnder(NikuTextStyle)?, NikuTextStyle selected(NikuTextStyle)?}) → void

Available on NikuButton, provided by the ButtonStyleProxy extension

useThemeSelector(BuildContext context, {NikuButton light(NikuButton)?, NikuButton dark(NikuButton)?}) → void
inherited
widget(BuildContext context) → Widget
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited