NikuGridView class

Inheritance
Mixed-in types
Available extensions

Constructors

NikuGridView({Key? key, NikuGridViewType? type, int? itemCount, List<Widget>? children, Axis? scrollDirection, bool? reverse, ScrollController? controller, bool? primary, ScrollPhysics? physics, bool? shrinkWrap, NikuEdgeInsets? padding, double? mainAxisSpacing, double? crossAxisSpacing, double? childAspectRatio, bool? addAutomaticKeepAlives, bool? addRepaintBoundaries, bool? addSemanticIndexes, double? cacheExtent, int? semanticChildCount, DragStartBehavior? dragStartBehavior, ScrollViewKeyboardDismissBehavior? keyboardDismissBehavior, String? restorationId, Clip? clipBehavior, IndexedWidgetBuilder? itemBuilder, double? maxCrossAxisExtent, double? maxCrossExtent, SliverGridDelegate? gridDelegate, SliverChildBuilderDelegate? childrenDelegate})
NikuGridView.builder({Key? key, required IndexedWidgetBuilder itemBuilder, required SliverGridDelegate? gridDelegate, int? itemCount, Axis? scrollDirection, bool? reverse, ScrollController? controller, bool? primary, ScrollPhysics? physics, bool? shrinkWrap, NikuEdgeInsets? padding, double? mainAxisSpacing, double? crossAxisSpacing, double? childAspectRatio, bool? addAutomaticKeepAlives, bool? addRepaintBoundaries, bool? addSemanticIndexes, double? cacheExtent, int? semanticChildCount, DragStartBehavior? dragStartBehavior, ScrollViewKeyboardDismissBehavior? keyboardDismissBehavior, String? restorationId, Clip? clipBehavior, double? maxCrossExtent})
factory
NikuGridView.children({Key? key, Axis? scrollDirection, bool? reverse, ScrollController? controller, bool? primary, ScrollPhysics? physics, bool? shrinkWrap, NikuEdgeInsets? padding, required SliverGridDelegate gridDelegate, bool? addAutomaticKeepAlives, bool? addRepaintBoundaries, bool? addSemanticIndexes, double? cacheExtent, List<Widget>? children, int? semanticChildCount, DragStartBehavior? dragStartBehavior, Clip? clipBehavior, ScrollViewKeyboardDismissBehavior? keyboardDismissBehavior, String? restorationId})
factory
NikuGridView.count({List<Widget>? children, int? crossAxisCount, Key? key, Axis? scrollDirection, bool? reverse, ScrollController? controller, bool? primary, ScrollPhysics? physics, bool? shrinkWrap, EdgeInsetsGeometry? padding, double? mainAxisSpacing, double? crossAxisSpacing, double? childAspectRatio, bool? addAutomaticKeepAlives, bool? addRepaintBoundaries, bool? addSemanticIndexes, double? cacheExtent, int? semanticChildCount, DragStartBehavior? dragStartBehavior, ScrollViewKeyboardDismissBehavior? keyboardDismissBehavior, String? restorationId, Clip? clipBehavior})
factory
NikuGridView.custom({Key? key, Axis? scrollDirection, bool? reverse, ScrollController? controller, bool? primary, ScrollPhysics? physics, bool? shrinkWrap, EdgeInsetsGeometry? padding, required SliverGridDelegate gridDelegate, required IndexedWidgetBuilder itemBuilder, int? itemCount, bool? addAutomaticKeepAlives, bool? addRepaintBoundaries, bool? addSemanticIndexes, double? cacheExtent, int? semanticChildCount, DragStartBehavior? dragStartBehavior, ScrollViewKeyboardDismissBehavior? keyboardDismissBehavior, String? restorationId, Clip? clipBehavior})
factory
NikuGridView.extent({Key? key, Axis? scrollDirection, bool? reverse, ScrollController? controller, bool? primary, ScrollPhysics? physics, bool? shrinkWrap, EdgeInsetsGeometry? padding, required double maxCrossAxisExtent, double? mainAxisSpacing, double? crossAxisSpacing, double? childAspectRatio, bool? addAutomaticKeepAlives, bool? addRepaintBoundaries, bool? addSemanticIndexes, double? cacheExtent, List<Widget>? children, int? semanticChildCount, DragStartBehavior? dragStartBehavior, ScrollViewKeyboardDismissBehavior? keyboardDismissBehavior, String? restorationId, Clip? clipBehavior})
factory

Properties

$parent → Niku
finalinherited
addAutomaticKeepAlives ↔ bool?
getter/setter pair
addRepaintBoundaries ↔ bool?
getter/setter pair
addSemanticIndexes ↔ bool?
getter/setter pair
antiAlias → void
no setterinherited
antiAliasWithSaveLayer → void
no setterinherited
apply ← NikuGridView?
no getteroverride
aspect ← double
no getteroverride
aspectRatio ← double
no getteroverride
boxConstraints ← BoxConstraints
no getterinherited
cacheExtent ↔ double?
getter/setter pair
childAspectRatio ↔ double?
getter/setter pair
children ↔ List<Widget>?
getter/setter pair
childrenDelegate ↔ SliverChildBuilderDelegate?
getter/setter pair
clip ↔ Clip?
getter/setter pairinherited
clipBehavior ↔ Clip?
getter/setter pair
controller ↔ ScrollController?
getter/setter pair
copied → NikuGridView
no setteroverride
count ← int
no getter
crossAxisSpacing ↔ double?
getter/setter pair
deps ↔ List
getter/setter pairinherited
dragStartBehavior ↔ DragStartBehavior?
getter/setter pair
expanded → dynamic
no setterinherited
fh ← double
no getterinherited
fill → void
no setterinherited
flex ↔ int
getter/setter pairinherited
formKey ← Key
no getterinherited
fractionH ← double
no getterinherited
fractionHeight ← double
no getterinherited
fractionSize ← List<double>
no getterinherited
fractionW ← double
no getterinherited
fractionWidth ← double
no getterinherited
freezed → void
no setterinherited
fullHeight → void
no setterinherited
fullSize → void
no setterinherited
fullWidth → void
no setterinherited
fw ← double
no getterinherited
grid ← int
no getter
gridDelegate ↔ SliverGridDelegate?
getter/setter pair
h ← double
no getterinherited
h100 → void
no setterinherited
hardEdge → void
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
height ← double
no getterinherited
heightPercent ← double
no getterinherited
hFactor ← double
no getterinherited
hFull → void
no setterinherited
hidden → dynamic
no setterinherited
hMax ← double
no getterinherited
hMin ← double
no getterinherited
hPercent ← double
no getterinherited
itemBuilder ↔ IndexedWidgetBuilder?
getter/setter pair
itemCount ↔ int?
getter/setter pair
key → Key?
Controls how one widget replaces another widget in the tree.
finalinherited
keyboardDismissBehavior ↔ ScrollViewKeyboardDismissBehavior?
getter/setter pair
m ← double
no getterinherited
mainAxisSpacing ↔ double?
getter/setter pair
margin ← EdgeInsets
no getterinherited
maxCrossAxisExtent ↔ double?
getter/setter pair
maxCrossExtent ↔ double?
getter/setter pair
maxH ← double
no getterinherited
maxHeight ← double
no getterinherited
maxSize ← List<double>
no getterinherited
maxW ← double
no getterinherited
maxWidth ← double
no getterinherited
mb ← double
no getterinherited
minH ← double
no getterinherited
minHeight ← double
no getterinherited
minSize ← List<double>
no getterinherited
minW ← double
no getterinherited
minWidth ← double
no getterinherited
ml ← double
no getterinherited
mr ← double
no getterinherited
mt ← double
no getterinherited
mx ← double
no getterinherited
my ← double
no getterinherited
n → NikuExplictParentBuilder
no setterinherited
niku → Niku

Available on Widget, provided by the NikuTransform extension

no setter
noClip → void
no setterinherited
p ← double
no getterinherited
padding ↔ NikuEdgeInsets?
getter/setter pairoverride
parent → NikuExplictParentBuilder
no setterinherited
pb ← double
no getterinherited
physics ↔ ScrollPhysics?
getter/setter pair
pl ← double
no getterinherited
pr ← double
no getterinherited
primary ↔ bool?
getter/setter pair
pt ← double
no getterinherited
px ← double
no getterinherited
py ← double
no getterinherited
ratio ← double
no getteroverride
restorationId ↔ String?
getter/setter pair
reverse ↔ bool?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
scrollable → void
no setterinherited
scrollDirection ↔ Axis?
getter/setter pair
self → NikuGridView
no setteroverride
semanticChildCount ↔ int?
getter/setter pair
shrinkWrap ↔ bool?
getter/setter pair
sizePercent ← List<double>
no getterinherited
sliverToBox → void
no setterinherited
theme ← ThemeData
no getterinherited
tip ← String
no getterinherited
tooltip ← String
no getterinherited
type ↔ NikuGridViewType?
getter/setter pair
visible ← bool
no getterinherited
w ← double
no getterinherited
w100 → void
no setterinherited
wFactor ← double
no getterinherited
wFull → void
no setterinherited
width ← double
no getterinherited
widthPercent ← double
no getterinherited
wMax ← double
no getterinherited
wMin ← double
no getterinherited
wPercent ← double
no getterinherited
wrap → dynamic
Cancel parent size inheritance by wrapping the widget with a Wrap.
no setterinherited

Methods

build(BuildContext _) → Widget
inherited
createElement() → StatelessElement
Creates a StatelessElement to manage this widget's location in the tree.
inherited
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
of(NikuGridView? v) → void
inherited
on({void tapDown(TapDownDetails)?, void tapUp(TapUpDetails)?, VoidCallback? tap, VoidCallback? tapCancel, VoidCallback? secondaryTap, void secondaryTapDown(TapDownDetails)?, void secondaryTapUp(TapUpDetails)?, VoidCallback? secondaryTapCancel, void tertiaryTapDown(TapDownDetails)?, void tertiaryTapUp(TapUpDetails)?, VoidCallback? tertiaryTapCancel, void doubleTapDown(TapDownDetails)?, VoidCallback? doubleTap, VoidCallback? doubleTapCancel, VoidCallback? longPress, void longPressStart(LongPressStartDetails)?, void longPressMoveUpdate(LongPressMoveUpdateDetails)?, VoidCallback? longPressUp, void longPressEnd(LongPressEndDetails)?, VoidCallback? secondaryLongPress, void secondaryLongPressStart(LongPressStartDetails)?, void secondaryLongPressMoveUpdate(LongPressMoveUpdateDetails)?, VoidCallback? secondaryLongPressUp, void secondaryLongPressEnd(LongPressEndDetails)?, void verticalDragDown(DragDownDetails)?, void verticalDragStart(DragStartDetails)?, void verticalDragUpdate(DragUpdateDetails)?, void verticalDragEnd(DragEndDetails)?, VoidCallback? verticalDragCancel, void horizontalDragDown(DragDownDetails)?, void horizontalDragStart(DragStartDetails)?, void horizontalDragUpdate(DragUpdateDetails)?, void horizontalDragEnd(DragEndDetails)?, VoidCallback? horizontalDragCancel, void forcePressStart(ForcePressDetails)?, void forcePressPeak(ForcePressDetails)?, void forcePressUpdate(ForcePressDetails)?, void forcePressEnd(ForcePressDetails)?, void panDown(DragDownDetails)?, void panStart(DragStartDetails)?, void panUpdate(DragUpdateDetails)?, void panEnd(DragEndDetails)?, VoidCallback? panCancel, void scaleStart(ScaleStartDetails)?, void scaleUpdate(ScaleUpdateDetails)?, void scaleEnd(ScaleEndDetails)?}) → void
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A short, textual description of this widget.
inherited
use(List<NikuGridView> v) → void
inherited
useAnimationBuilder({required Widget builder(BuildContext context, Widget child), required AnimationController animation}) → void
inherited
useDarkMode(BuildContext context, NikuGridView builder(NikuGridView, bool)) → void
inherited
useForm({Key? key, AutovalidateMode? autovalidateMode, Future<bool> onWillPop()?, void onChanged()?}) → void
inherited
useItemBuilder(Widget builder(BuildContext, int)) → void
useParent(Widget compose(Niku)) → void
inherited
usePlatform(BuildContext context, {NikuGridView android(NikuGridView)?, NikuGridView iOS(NikuGridView)?, NikuGridView fuchsia(NikuGridView)?, NikuGridView linux(NikuGridView)?, NikuGridView macOS(NikuGridView)?, NikuGridView windows(NikuGridView)?, NikuGridView web(NikuGridView)?}) → void
inherited
useQuery(BuildContext context, NikuGridView builder(NikuGridView, MediaQueryData)) → void
inherited
useScreen(BuildContext context, {NikuGridView base(NikuGridView)?, NikuGridView xs(NikuGridView)?, NikuGridView sm(NikuGridView)?, NikuGridView md(NikuGridView)?, NikuGridView lg(NikuGridView)?, NikuGridView xl(NikuGridView)?}) → void
void useScreen({ // > 568px Widget Function(Niku)? base, // 568 - 640px Widget Function(Niku)? xs, // 640 - 768px Widget Function(Niku)? sm, // 768 - 920px Widget Function(Niku)? md, // 920 - 1024px Widget Function(Niku)? lg, // > 1024px Widget Function(Niku)? xl, })
inherited
useScrollView({ScrollController? controller, Axis scrollDirection = Axis.vertical, bool? primary, bool reverse = false, ScrollPhysics? physics, DragStartBehavior dragStartBehavior = DragStartBehavior.start, String? restorationId}) → void
inherited
useSize(BuildContext context, NikuGridView builder(NikuGridView, Size)) → void
inherited
useThemeSelector(BuildContext context, {NikuGridView light(NikuGridView)?, NikuGridView dark(NikuGridView)?}) → void
inherited
widget(BuildContext context) → Widget
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited