NikuSwitch class

Inheritance
Mixed-in types
Available extensions

Constructors

NikuSwitch(bool? value, {Key? key, NikuState<Color?>? thumbColorState, NikuState<Color?>? trackColorState, NikuState<Icon?>? thumbIconState, NikuState<Color?>? overlayColorState, ValueChanged<bool>? onChanged, Color? activeColor, Color? activeTrackColor, Color? inactiveThumbColor, Color? inactiveTrackColor, ImageProvider<Object>? activeThumbImage, ImageErrorListener? onActiveThumbImageError, ImageProvider<Object>? inactiveThumbImage, ImageErrorListener? onInactiveThumbImageError, Color? thumbColor, Color? trackColor, MaterialTapTargetSize? materialTapTargetSize, DragStartBehavior? dragStartBehavior, MouseCursor? mouseCursor, Color? focusColor, Color? hoverColor, Color? overlayColor, double? splashRadius, FocusNode? focusNode, bool? autofocus, Icon? thumbIcon, bool adaptive = false, bool cupertino = false})
NikuSwitch.adaptive({Key? key, NikuState<Color>? thumbColorState, NikuState<Color>? trackColorState, NikuState<Color>? overlayColorState, bool? value, ValueChanged<bool>? onChanged, Color? activeColor, Color? activeTrackColor, Color? inactiveThumbColor, Color? inactiveTrackColor, ImageProvider<Object>? activeThumbImage, ImageErrorListener? onActiveThumbImageError, ImageProvider<Object>? inactiveThumbImage, ImageErrorListener? onInactiveThumbImageError, MaterialTapTargetSize? materialTapTargetSize, DragStartBehavior? dragStartBehavior, MouseCursor? mouseCursor, Color? focusColor, Color? hoverColor, double? splashRadius, FocusNode? focusNode, bool? autofocus, Color? thumbColor, Color? trackColor, Color? overlayColor, Icon? thumbIcon})
factory
NikuSwitch.cupertino({Key? key, NikuState<Color>? thumbColorState, NikuState<Color>? trackColorState, NikuState<Color>? overlayColorState, bool? value, ValueChanged<bool>? onChanged, Color? activeColor, Color? activeTrackColor, Color? inactiveThumbColor, Color? inactiveTrackColor, ImageProvider<Object>? activeThumbImage, ImageErrorListener? onActiveThumbImageError, ImageProvider<Object>? inactiveThumbImage, ImageErrorListener? onInactiveThumbImageError, MaterialTapTargetSize? materialTapTargetSize, DragStartBehavior? dragStartBehavior, MouseCursor? mouseCursor, Color? focusColor, Color? hoverColor, double? splashRadius, FocusNode? focusNode, bool? autofocus, Color? thumbColor, Color? trackColor, Color? overlayColor, Icon? thumbIcon})
factory

Properties

$parent → Niku
finalinherited
activeColor ↔ Color?
getter/setter pair
activeThumbImage ↔ ImageProvider<Object>?
getter/setter pair
activeTrackColor ↔ Color?
getter/setter pair
adaptive ↔ bool
getter/setter pair
apply ← NikuSwitch?
no getteroverride
aspect ← double
no getterinherited
aspectRatio ← double
no getterinherited
autofocus ↔ bool?
getter/setter pair
boxConstraints ← BoxConstraints
no getterinherited
copied → NikuSwitch
no setteroverride
cupertino ↔ bool
getter/setter pair
deps ↔ List
getter/setter pairinherited
dragStartBehavior ↔ DragStartBehavior?
getter/setter pair
expanded → dynamic
no setterinherited
fh ← double
no getterinherited
fill → void
no setterinherited
flex ↔ int
getter/setter pairinherited
focusColor ↔ Color?
getter/setter pair
focusNode ↔ FocusNode?
getter/setter pairoverride
formKey ← Key
no getterinherited
fractionH ← double
no getterinherited
fractionHeight ← double
no getterinherited
fractionSize ← List<double>
no getterinherited
fractionW ← double
no getterinherited
fractionWidth ← double
no getterinherited
freezed → void
no setterinherited
fullHeight → void
no setterinherited
fullSize → void
no setterinherited
fullWidth → void
no setterinherited
fw ← double
no getterinherited
h ← double
no getterinherited
h100 → void
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
height ← double
no getterinherited
heightPercent ← double
no getterinherited
hFactor ← double
no getterinherited
hFull → void
no setterinherited
hidden → dynamic
no setterinherited
hMax ← double
no getterinherited
hMin ← double
no getterinherited
hoverColor ↔ Color?
getter/setter pair
hPercent ← double
no getterinherited
inactiveThumbColor ↔ Color?
getter/setter pair
inactiveThumbImage ↔ ImageProvider<Object>?
getter/setter pair
inactiveTrackColor ↔ Color?
getter/setter pair
key → Key?
Controls how one widget replaces another widget in the tree.
finalinherited
m ← double
no getterinherited
margin ← EdgeInsets
no getterinherited
materialTapTargetSize ↔ MaterialTapTargetSize?
getter/setter pair
maxH ← double
no getterinherited
maxHeight ← double
no getterinherited
maxSize ← List<double>
no getterinherited
maxW ← double
no getterinherited
maxWidth ← double
no getterinherited
mb ← double
no getterinherited
minH ← double
no getterinherited
minHeight ← double
no getterinherited
minSize ← List<double>
no getterinherited
minW ← double
no getterinherited
minWidth ← double
no getterinherited
ml ← double
no getterinherited
mouseCursor ↔ MouseCursor?
getter/setter pair
mr ← double
no getterinherited
mt ← double
no getterinherited
mx ← double
no getterinherited
my ← double
no getterinherited
n → NikuExplictParentBuilder
no setterinherited
niku → Niku

Available on Widget, provided by the NikuTransform extension

no setter
onActiveThumbImageError ↔ ImageErrorListener?
getter/setter pair
onChanged ↔ ValueChanged<bool>?
getter/setter pair
onInactiveThumbImageError ↔ ImageErrorListener?
getter/setter pair
overlayColor ← Color?
no getter
overlayColorState ↔ NikuState<Color?>?
getter/setter pair
parent → NikuExplictParentBuilder
no setterinherited
ratio ← double
no getterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
scrollable → void
no setterinherited
self → NikuSwitch
no setteroverride
sizePercent ← List<double>
no getterinherited
sliverToBox → void
no setterinherited
splashRadius ↔ double?
getter/setter pair
theme ← ThemeData
no getterinherited
thumbColor ← Color?
no getter
thumbColorState ↔ NikuState<Color?>?
getter/setter pair
thumbIcon ← Icon
no getter
thumbIconState ↔ NikuState<Icon?>?
getter/setter pair
tip ← String
no getterinherited
tooltip ← String
no getterinherited
trackColor ← Color?
no getter
trackColorState ↔ NikuState<Color?>?
getter/setter pair
value ↔ bool?
getter/setter pair
visible ← bool
no getterinherited
w ← double
no getterinherited
w100 → void
no setterinherited
wFactor ← double
no getterinherited
wFull → void
no setterinherited
width ← double
no getterinherited
widthPercent ← double
no getterinherited
wMax ← double
no getterinherited
wMin ← double
no getterinherited
wPercent ← double
no getterinherited
wrap → dynamic
Cancel parent size inheritance by wrapping the widget with a Wrap.
no setterinherited

Methods

build(BuildContext _) → Widget
inherited
createElement() → StatelessElement
Creates a StatelessElement to manage this widget's location in the tree.
inherited
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
of(NikuSwitch? v) → void
inherited
on({void tapDown(TapDownDetails)?, void tapUp(TapUpDetails)?, VoidCallback? tap, VoidCallback? tapCancel, VoidCallback? secondaryTap, void secondaryTapDown(TapDownDetails)?, void secondaryTapUp(TapUpDetails)?, VoidCallback? secondaryTapCancel, void tertiaryTapDown(TapDownDetails)?, void tertiaryTapUp(TapUpDetails)?, VoidCallback? tertiaryTapCancel, void doubleTapDown(TapDownDetails)?, VoidCallback? doubleTap, VoidCallback? doubleTapCancel, VoidCallback? longPress, void longPressStart(LongPressStartDetails)?, void longPressMoveUpdate(LongPressMoveUpdateDetails)?, VoidCallback? longPressUp, void longPressEnd(LongPressEndDetails)?, VoidCallback? secondaryLongPress, void secondaryLongPressStart(LongPressStartDetails)?, void secondaryLongPressMoveUpdate(LongPressMoveUpdateDetails)?, VoidCallback? secondaryLongPressUp, void secondaryLongPressEnd(LongPressEndDetails)?, void verticalDragDown(DragDownDetails)?, void verticalDragStart(DragStartDetails)?, void verticalDragUpdate(DragUpdateDetails)?, void verticalDragEnd(DragEndDetails)?, VoidCallback? verticalDragCancel, void horizontalDragDown(DragDownDetails)?, void horizontalDragStart(DragStartDetails)?, void horizontalDragUpdate(DragUpdateDetails)?, void horizontalDragEnd(DragEndDetails)?, VoidCallback? horizontalDragCancel, void forcePressStart(ForcePressDetails)?, void forcePressPeak(ForcePressDetails)?, void forcePressUpdate(ForcePressDetails)?, void forcePressEnd(ForcePressDetails)?, void panDown(DragDownDetails)?, void panStart(DragStartDetails)?, void panUpdate(DragUpdateDetails)?, void panEnd(DragEndDetails)?, VoidCallback? panCancel, void scaleStart(ScaleStartDetails)?, void scaleUpdate(ScaleUpdateDetails)?, void scaleEnd(ScaleEndDetails)?}) → void
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A short, textual description of this widget.
inherited
use(List<NikuSwitch> v) → void
inherited
useAnimationBuilder({required Widget builder(BuildContext context, Widget child), required AnimationController animation}) → void
inherited
useDarkMode(BuildContext context, NikuSwitch builder(NikuSwitch, bool)) → void
inherited
useFocus(FocusNode builder(FocusNode?), {String? debugLabel, FocusOnKeyCallback? onKey, FocusOnKeyEventCallback? onKeyEvent, bool skipTraversal = false, bool canRequestFocus = true, bool descendantsAreFocusable = true}) → dynamic
inherited
useFocusNode(FocusNode builder(FocusNode?), {String? debugLabel, FocusOnKeyCallback? onKey, FocusOnKeyEventCallback? onKeyEvent, bool skipTraversal = false, bool canRequestFocus = true, bool descendantsAreFocusable = true}) → dynamic
inherited
useForm({Key? key, AutovalidateMode? autovalidateMode, Future<bool> onWillPop()?, void onChanged()?}) → void
inherited
useParent(Widget compose(Niku)) → void
inherited
usePlatform(BuildContext context, {NikuSwitch android(NikuSwitch)?, NikuSwitch iOS(NikuSwitch)?, NikuSwitch fuchsia(NikuSwitch)?, NikuSwitch linux(NikuSwitch)?, NikuSwitch macOS(NikuSwitch)?, NikuSwitch windows(NikuSwitch)?, NikuSwitch web(NikuSwitch)?}) → void
inherited
useQuery(BuildContext context, NikuSwitch builder(NikuSwitch, MediaQueryData)) → void
inherited
useScreen(BuildContext context, {NikuSwitch base(NikuSwitch)?, NikuSwitch xs(NikuSwitch)?, NikuSwitch sm(NikuSwitch)?, NikuSwitch md(NikuSwitch)?, NikuSwitch lg(NikuSwitch)?, NikuSwitch xl(NikuSwitch)?}) → void
void useScreen({ // > 568px Widget Function(Niku)? base, // 568 - 640px Widget Function(Niku)? xs, // 640 - 768px Widget Function(Niku)? sm, // 768 - 920px Widget Function(Niku)? md, // 920 - 1024px Widget Function(Niku)? lg, // > 1024px Widget Function(Niku)? xl, })
inherited
useScrollView({ScrollController? controller, Axis scrollDirection = Axis.vertical, bool? primary, bool reverse = false, ScrollPhysics? physics, DragStartBehavior dragStartBehavior = DragStartBehavior.start, String? restorationId}) → void
inherited
useSize(BuildContext context, NikuSwitch builder(NikuSwitch, Size)) → void
inherited
useThemeSelector(BuildContext context, {NikuSwitch light(NikuSwitch)?, NikuSwitch dark(NikuSwitch)?}) → void
inherited
useThumbIcon({Icon? all, Icon? disabled, Icon? dragged, Icon? error, Icon? focused, Icon? hovered, Icon? pressed, Icon? scrolledUnder, Icon? selected, Icon? base}) → void
widget(BuildContext context) → Widget
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited