NikuTextFormField class

Inheritance
Mixed-in types
Available extensions

Constructors

NikuTextFormField({Key? key, Widget? label, String? labelText, String? hintText, TextEditingController? controller, String? initialValue, FocusNode? focusNode, NikuInputDecoration? decoration, TextInputType? keyboardType, TextCapitalization? textCapitalization, TextInputAction? textInputAction, NikuTextStyle? style, NikuStrutStyle? strutStyle, TextDirection? textDirection, TextAlign? textAlign, TextAlignVertical? textAlignVertical, bool? autofocus, bool? readOnly, ToolbarOptions? toolbarOptions, bool? showCursor, String? obscuringCharacter, bool? obscureText, bool? autocorrect, SmartDashesType? smartDashesType, SmartQuotesType? smartQuotesType, bool? enableSuggestions, bool? autovalidate, bool? maxLengthEnforced, MaxLengthEnforcement? maxLengthEnforcement, int? maxLines, int? minLines, bool? expands, int? maxLength, ValueChanged<String>? onChanged, GestureTapCallback? onTap, VoidCallback? onEditingComplete, ValueChanged<String>? onFieldSubmitted, FormFieldSetter<String>? onSaved, FormFieldValidator<String>? validator, List<TextInputFormatter>? inputFormatters, bool? enabled, double? cursorWidth, double? cursorHeight, Radius? cursorRadius, Color? cursorColor, Brightness? keyboardAppearance, EdgeInsets? scrollPadding, bool? enableInteractiveSelection, TextSelectionControls? selectionControls, InputCounterWidgetBuilder? buildCounter, ScrollPhysics? scrollPhysics, Iterable<String>? autofillHints, ScrollController? scrollController, String? restorationId, AutovalidateMode? autovalidateMode, bool? enableIMEPersonalizedLearning, EditableTextContextMenuBuilder? contextMenuBuilder, TextMagnifierConfiguration? magnifierConfiguration, SpellCheckConfiguration? spellCheckConfiguration, bool adaptive = false, bool cupertino = false})
NikuTextFormField.adaptive({Widget? label, String? labelText, String? hintText, TextEditingController? controller, String? initialValue, FocusNode? focusNode, NikuInputDecoration? decoration, TextInputType? keyboardType, TextCapitalization? textCapitalization, TextInputAction? textInputAction, NikuTextStyle? style, NikuStrutStyle? strutStyle, TextDirection? textDirection, TextAlign? textAlign, TextAlignVertical? textAlignVertical, bool? autofocus, bool? readOnly, ToolbarOptions? toolbarOptions, bool? showCursor, String? obscuringCharacter, bool? obscureText, bool? autocorrect, SmartDashesType? smartDashesType, SmartQuotesType? smartQuotesType, bool? enableSuggestions, bool? autovalidate, bool? maxLengthEnforced, MaxLengthEnforcement? maxLengthEnforcement, int? maxLines, int? minLines, bool? expands, int? maxLength, ValueChanged<String>? onChanged, GestureTapCallback? onTap, VoidCallback? onEditingComplete, ValueChanged<String>? onFieldSubmitted, FormFieldSetter<String>? onSaved, FormFieldValidator<String>? validator, List<TextInputFormatter>? inputFormatters, bool? enabled, double? cursorWidth, double? cursorHeight, Radius? cursorRadius, Color? cursorColor, Brightness? keyboardAppearance, EdgeInsets? scrollPadding, bool? enableInteractiveSelection, TextSelectionControls? selectionControls, InputCounterWidgetBuilder? buildCounter, ScrollPhysics? scrollPhysics, Iterable<String>? autofillHints, AutovalidateMode? autovalidateMode, ScrollController? scrollController, String? restorationId, bool? enableIMEPersonalizedLearning, EditableTextContextMenuBuilder? contextMenuBuilder, TextMagnifierConfiguration? magnifierConfiguration, SpellCheckConfiguration? spellCheckConfiguration})
factory
NikuTextFormField.cupertino({Widget? label, String? labelText, String? hintText, TextEditingController? controller, String? initialValue, FocusNode? focusNode, NikuInputDecoration? decoration, TextInputType? keyboardType, TextCapitalization? textCapitalization, TextInputAction? textInputAction, NikuTextStyle? style, NikuStrutStyle? strutStyle, TextDirection? textDirection, TextAlign? textAlign, TextAlignVertical? textAlignVertical, bool? autofocus, bool? readOnly, ToolbarOptions? toolbarOptions, bool? showCursor, String? obscuringCharacter, bool? obscureText, bool? autocorrect, SmartDashesType? smartDashesType, SmartQuotesType? smartQuotesType, bool? enableSuggestions, bool? autovalidate, bool? maxLengthEnforced, MaxLengthEnforcement? maxLengthEnforcement, int? maxLines, int? minLines, bool? expands, int? maxLength, ValueChanged<String>? onChanged, GestureTapCallback? onTap, VoidCallback? onEditingComplete, ValueChanged<String>? onFieldSubmitted, FormFieldSetter<String>? onSaved, FormFieldValidator<String>? validator, List<TextInputFormatter>? inputFormatters, bool? enabled, double? cursorWidth, double? cursorHeight, Radius? cursorRadius, Color? cursorColor, Brightness? keyboardAppearance, EdgeInsets? scrollPadding, bool? enableInteractiveSelection, TextSelectionControls? selectionControls, InputCounterWidgetBuilder? buildCounter, ScrollPhysics? scrollPhysics, Iterable<String>? autofillHints, AutovalidateMode? autovalidateMode, ScrollController? scrollController, String? restorationId, bool? enableIMEPersonalizedLearning, EditableTextContextMenuBuilder? contextMenuBuilder, TextMagnifierConfiguration? magnifierConfiguration, SpellCheckConfiguration? spellCheckConfiguration})
factory
NikuTextFormField.hint(String? hint, {Key? key, Widget? label, String? labelText, TextEditingController? controller, String? initialValue, FocusNode? focusNode, NikuInputDecoration? decoration, TextInputType? keyboardType, TextCapitalization? textCapitalization, TextInputAction? textInputAction, NikuTextStyle? style, NikuStrutStyle? strutStyle, TextDirection? textDirection, TextAlign? textAlign, TextAlignVertical? textAlignVertical, bool? autofocus, bool? readOnly, ToolbarOptions? toolbarOptions, bool? showCursor, String? obscuringCharacter, bool? obscureText, bool? autocorrect, SmartDashesType? smartDashesType, SmartQuotesType? smartQuotesType, bool? enableSuggestions, bool? autovalidate, bool? maxLengthEnforced, MaxLengthEnforcement? maxLengthEnforcement, int? maxLines, int? minLines, bool? expands, int? maxLength, ValueChanged<String>? onChanged, GestureTapCallback? onTap, VoidCallback? onEditingComplete, ValueChanged<String>? onFieldSubmitted, FormFieldSetter<String>? onSaved, FormFieldValidator<String>? validator, List<TextInputFormatter>? inputFormatters, bool? enabled, double? cursorWidth, double? cursorHeight, Radius? cursorRadius, Color? cursorColor, Brightness? keyboardAppearance, EdgeInsets? scrollPadding, bool? enableInteractiveSelection, TextSelectionControls? selectionControls, InputCounterWidgetBuilder? buildCounter, ScrollPhysics? scrollPhysics, Iterable<String>? autofillHints, AutovalidateMode? autovalidateMode, ScrollController? scrollController, String? restorationId, bool? enableIMEPersonalizedLearning, EditableTextContextMenuBuilder? contextMenuBuilder, TextMagnifierConfiguration? magnifierConfiguration, SpellCheckConfiguration? spellCheckConfiguration, bool adaptive = false, bool cupertino = false})
factory
NikuTextFormField.label(String? label, {Key? key, String? hintText, TextEditingController? controller, String? initialValue, FocusNode? focusNode, NikuInputDecoration? decoration, TextInputType? keyboardType, TextCapitalization? textCapitalization, TextInputAction? textInputAction, NikuTextStyle? style, NikuStrutStyle? strutStyle, TextDirection? textDirection, TextAlign? textAlign, TextAlignVertical? textAlignVertical, bool? autofocus, bool? readOnly, ToolbarOptions? toolbarOptions, bool? showCursor, String? obscuringCharacter, bool? obscureText, bool? autocorrect, SmartDashesType? smartDashesType, SmartQuotesType? smartQuotesType, bool? enableSuggestions, bool? autovalidate, bool? maxLengthEnforced, MaxLengthEnforcement? maxLengthEnforcement, int? maxLines, int? minLines, bool? expands, int? maxLength, ValueChanged<String>? onChanged, GestureTapCallback? onTap, VoidCallback? onEditingComplete, ValueChanged<String>? onFieldSubmitted, FormFieldSetter<String>? onSaved, FormFieldValidator<String>? validator, List<TextInputFormatter>? inputFormatters, bool? enabled, double? cursorWidth, double? cursorHeight, Radius? cursorRadius, Color? cursorColor, Brightness? keyboardAppearance, EdgeInsets? scrollPadding, bool? enableInteractiveSelection, TextSelectionControls? selectionControls, InputCounterWidgetBuilder? buildCounter, ScrollPhysics? scrollPhysics, Iterable<String>? autofillHints, AutovalidateMode? autovalidateMode, ScrollController? scrollController, String? restorationId, bool? enableIMEPersonalizedLearning, EditableTextContextMenuBuilder? contextMenuBuilder, TextMagnifierConfiguration? magnifierConfiguration, SpellCheckConfiguration? spellCheckConfiguration, bool adaptive = false, bool cupertino = false})
factory

Properties

$parent → Niku
finalinherited
aboveline → void
no setterinherited
adaptive ↔ bool
getter/setter pair
addressKeyboard → void
no setterinherited
alignLabelWithHint ← bool?
no getterinherited
alwaysFloat → void
no setterinherited
apply ← NikuTextFormField?
no getteroverride
applyConstraints ← NikuBoxConstraints
no getterinherited
applyDecoration ← NikuInputDecoration
no getterinherited
applyErrorStyle ← NikuTextStyle
no getterinherited
applyFloatingLabelStyle ← NikuTextStyle
no getterinherited
applyHelperStyle ← NikuTextStyle
no getterinherited
applyHintStyle ← NikuTextStyle
no getterinherited
applyLabelStyle ← NikuTextStyle
no getterinherited
applyPrefixIconConstraints ← NikuBoxConstraints
no getterinherited
applyPrefixStyle ← NikuTextStyle
no getterinherited
applySturtStyle ← NikuStrutStyle
no getterinherited
applySuffixIconConstraints ← NikuBoxConstraints
no getterinherited
applySuffixStyle ← NikuTextStyle
no getterinherited
applyTextStyle ← NikuTextStyle
no getterinherited
asPassword ↔ bool
getter/setter pair
aspect ← double
no getterinherited
aspectRatio ← double
no getterinherited
autocorrect ↔ bool?
getter/setter pair
autofillHints ↔ Iterable<String>?
getter/setter pair
autoFloat → void
no setterinherited
autofocus ↔ bool?
getter/setter pair
autovalidate ↔ bool?
getter/setter pair
autovalidateMode ↔ AutovalidateMode?
getter/setter pair
backgroundColor ← Color?
no getterinherited
baseBorderColor ← Color
no getterinherited
baseBorderWidth ← double
no getterinherited
bg ← Color
no getterinherited
bodyLarge ← BuildContext
no getterinherited
bodyMedium ← BuildContext
no getterinherited
bodySmall ← BuildContext
no getterinherited
bold → void
no setterinherited
border ← NikuInputBorder?
no getterinherited
borderColor ← Color
no getterinherited
borderWidth ← double
no getterinherited
boxConstraints ← BoxConstraints
no getterinherited
buildCounter ↔ InputCounterWidgetBuilder?
getter/setter pair
capitalCharacters → void
no setterinherited
capitalNone → void
no setterinherited
capitalSentences → void
no setterinherited
capitalWords → void
no setterinherited
center → void
no setterinherited
color ← Color?
no getterinherited
constraints ← NikuBoxConstraints?
no getterinherited
contentPadding ← NikuEdgeInsets?
no getterinherited
contextMenuBuilder ↔ EditableTextContextMenuBuilder?
getter/setter pair
continueAction → void
no setterinherited
controller ↔ TextEditingController?
getter/setter pair
copied → NikuTextFormField
no setteroverride
counter ← Widget?
no getterinherited
counterStyle ← NikuTextStyle?
no getterinherited
counterText ← String?
no getterinherited
cupertino ↔ bool
getter/setter pair
cursorColor ↔ Color?
getter/setter pair
cursorHeight ↔ double?
getter/setter pair
cursorRadius ↔ Radius?
getter/setter pair
cursorWidth ↔ double?
getter/setter pair
darkKeyboard → void
no setter
dashed → void
no setterinherited
datetimeKeyboard → void
no setterinherited
debugLabel ← String?
no getterinherited
decimal → void
no setterinherited
decoration ↔ NikuInputDecoration?
getter/setter pairoverride
decorationColor ← Color?
no getterinherited
decorationStyle ← TextDecorationStyle?
no getterinherited
decorationThickness ← double?
no getterinherited
deps ↔ List
getter/setter pairinherited
disabledBorder ← NikuInputBorder?
no getterinherited
disabledBorderColor ← Color
no getterinherited
disabledBorderWidth ← double
no getterinherited
displayLarge ← BuildContext
no getterinherited
displayMedium ← BuildContext
no getterinherited
displaySmall ← BuildContext
no getterinherited
doneAction → void
no setterinherited
dotted → void
no setterinherited
emailKeyboard → void
no setterinherited
emergencyCallAction → void
no setterinherited
enabled ↔ bool?
getter/setter pairoverride-setter
enabledBorder ← NikuInputBorder?
no getterinherited
enabledBorderColor ← Color
no getterinherited
enabledBorderWidth ← double
no getterinherited
enableIMEPersonalizedLearning ↔ bool?
getter/setter pair
enableInteractiveSelection ↔ bool?
getter/setter pair
enableSuggestions ↔ bool?
getter/setter pair
end → void
no setterinherited
errorBorder ← NikuInputBorder?
no getterinherited
errorBorderColor ← Color
no getterinherited
errorBorderWidth ← double
no getterinherited
errorMaxLines ← int?
no getterinherited
errorStyle ← NikuTextStyle?
no getterinherited
errorText ← String?
no getterinherited
expanded → dynamic
no setterinherited
expands ↔ bool?
getter/setter pair
fh ← double
no getterinherited
fill → void
no setterinherited
fillColor ← Color?
no getterinherited
filled ← bool?
no getterinherited
flex ↔ int
getter/setter pairinherited
floatingLabel ← FloatingLabelBehavior
no getterinherited
floatingLabelBehavior ← FloatingLabelBehavior?
no getterinherited
floatingLabelStyle ← NikuTextStyle?
no getterinherited
focusColor ← Color?
no getterinherited
focusedBorder ← NikuInputBorder?
no getterinherited
focusedBorderColor ← Color
no getterinherited
focusedBorderWidth ← double
no getterinherited
focusedErrorBorder ← NikuInputBorder?
no getterinherited
focusedErrorBorderColor ← Color
no getterinherited
focusedErrororderWidth ← double
no getterinherited
focusNode ↔ FocusNode?
getter/setter pairoverride
fontFamily ← String?
no getterinherited
fontFamilyFallback ← List<String>?
no getterinherited
fontFeatures ← List<FontFeature>?
no getterinherited
fontSize ← double?
no getterinherited
fontStyle ← FontStyle?
no getterinherited
fontWeight ← FontWeight?
no getterinherited
foreground ← Paint?
no getterinherited
formKey ← Key
no getterinherited
fractionH ← double
no getterinherited
fractionHeight ← double
no getterinherited
fractionSize ← List<double>
no getterinherited
fractionW ← double
no getterinherited
fractionWidth ← double
no getterinherited
freezed → void
no setterinherited
fullHeight → void
no setterinherited
fullSize → void
no setterinherited
fullWidth → void
no setterinherited
fw ← double
no getterinherited
goAction → void
no setterinherited
h ← double
no getterinherited
h100 → void
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
height ← double?
no getterinherited
heightPercent ← double
no getterinherited
helperMaxLines ← int?
no getterinherited
helperStyle ← NikuTextStyle?
no getterinherited
helperText ← String?
no getterinherited
hFactor ← double
no getterinherited
hFull → void
no setterinherited
hidden → dynamic
no setterinherited
hintMaxLines ← int?
no getterinherited
hintStyle ← NikuTextStyle?
no getterinherited
hintText ← String?
no getterinherited
hintTextDirection ← TextDirection?
no getterinherited
hMax ← double
no getterinherited
hMin ← double
no getterinherited
hoverColor ← Color?
no getterinherited
hPercent ← double
no getterinherited
icon ← Widget?
no getterinherited
inherit ← bool
no getterinherited
initialValue ↔ String?
getter/setter pair
inputFormatters ↔ List<TextInputFormatter>?
getter/setter pair
isCollapsed ← bool?
no getterinherited
isDense ← bool?
no getterinherited
isFilled → void
no setterinherited
italic → void
no setterinherited
joinAction → void
no setterinherited
justify → void
no setterinherited
key → Key?
Controls how one widget replaces another widget in the tree.
finalinherited
keyboardAppearance ↔ Brightness?
getter/setter pair
keyboardType ↔ TextInputType?
getter/setter pairoverride
label ← Widget?
no getterinherited
labelLarge ← BuildContext
no getterinherited
labelMedium ← BuildContext
no getterinherited
labelSmall ← BuildContext
no getterinherited
labelStyle ← NikuTextStyle?
no getterinherited
labelText ← String?
no getterinherited
leadingDistribution ← TextLeadingDistribution?
no getterinherited
left → void
no setterinherited
letterSpacing ← double?
no getterinherited
lightKeyboard → void
no setter
lineThrough → void
no setterinherited
locale ← Locale?
no getterinherited
ltr → void
no setterinherited
m ← double
no getterinherited
magnifierConfiguration ↔ TextMagnifierConfiguration?
getter/setter pair
margin ← EdgeInsets
no getterinherited
maxH ← double
no getterinherited
maxHeight ← double
no getterinherited
maxLength ↔ int?
getter/setter pair
maxLengthEnforced ↔ bool?
getter/setter pair
maxLengthEnforcement ↔ MaxLengthEnforcement?
getter/setter pair
maxLines ↔ int?
getter/setter pair
maxSize ← List<double>
no getterinherited
maxW ← double
no getterinherited
maxWidth ← double
no getterinherited
mb ← double
no getterinherited
minH ← double
no getterinherited
minHeight ← double
no getterinherited
minLines ↔ int?
getter/setter pair
minSize ← List<double>
no getterinherited
minW ← double
no getterinherited
minWidth ← double
no getterinherited
ml ← double
no getterinherited
mr ← double
no getterinherited
mt ← double
no getterinherited
multilineKeyboard → void
no setterinherited
mx ← double
no getterinherited
my ← double
no getterinherited
n → NikuExplictParentBuilder
no setterinherited
nameKeyboard → void
no setterinherited
neverFloat → void
no setterinherited
newLineAction → void
no setterinherited
nextAction → void
no setterinherited
niku → Niku

Available on Widget, provided by the NikuTransform extension

no setter
noDecoration → void
no setterinherited
noKeyboard → void
no setterinherited
noneAction → void
no setterinherited
noUnderline → void
no setterinherited
numberKeynoard → void
no setterinherited
obscureText ↔ bool?
getter/setter pair
obscuringCharacter ↔ String?
getter/setter pair
onChanged ↔ ValueChanged<String>?
getter/setter pair
onEditingComplete ↔ VoidCallback?
getter/setter pair
onFieldSubmitted ↔ ValueChanged<String>?
getter/setter pair
onSaved ↔ FormFieldSetter<String>?
getter/setter pair
onTap ↔ VoidCallback?
getter/setter pair
outlined → void
no setterinherited
overflow ← TextOverflow?
no getterinherited
p ← double
no getterinherited
package ← String?
no getterinherited
parent → NikuExplictParentBuilder
no setterinherited
passwordKeyboard → void
no setterinherited
pb ← double
no getterinherited
phoneKeybaord → void
no setterinherited
pl ← double
no getterinherited
pr ← double
no getterinherited
prefix ← Widget?
no getterinherited
prefixIcon ← Widget?
no getterinherited
prefixIconConstraints ← NikuBoxConstraints?
no getterinherited
prefixStyle ← NikuTextStyle?
no getterinherited
prefixText ← String?
no getterinherited
previousAction → void
no setterinherited
pt ← double
no getterinherited
px ← double
no getterinherited
py ← double
no getterinherited
ratio ← double
no getterinherited
readOnly ↔ bool?
getter/setter pair
restorationId ↔ String?
getter/setter pair
no setterinherited
rounded ↔ double
getter/setter pairinherited
routeAction → void
no setterinherited
rtl → void
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
scrollable → void
no setterinherited
scrollController ↔ ScrollController?
getter/setter pair
scrollPadding ↔ EdgeInsets?
getter/setter pair
scrollPhysics ↔ ScrollPhysics?
getter/setter pair
searchAction → void
no setterinherited
selectionControls ↔ TextSelectionControls?
getter/setter pair
self → NikuTextFormField
no setteroverride
semanticCounterText ← String?
no getterinherited
sendAction → void
no setterinherited
shadows ← List<Shadow>?
no getterinherited
showCursor ↔ bool?
getter/setter pair
singleLine → void
no setter
sizePercent ← List<double>
no getterinherited
sliverToBox → void
no setterinherited
smartDashesType ↔ SmartDashesType?
getter/setter pair
smartQuotesType ↔ SmartQuotesType?
getter/setter pair
solid → void
no setterinherited
spellCheckConfiguration ↔ SpellCheckConfiguration?
getter/setter pair
start → void
no setterinherited
strutStyle ↔ NikuStrutStyle?
getter/setter pairoverride
style ↔ NikuTextStyle?
getter/setter pairoverride
suffix ← Widget?
no getterinherited
suffixIcon ← Widget?
no getterinherited
suffixIconConstraints ← NikuBoxConstraints?
no getterinherited
suffixStyle ← NikuTextStyle?
no getterinherited
suffixText ← String?
no getterinherited
textAlign ↔ TextAlign?
getter/setter pairoverride
textAlignVertical ↔ TextAlignVertical?
getter/setter pair
textBackground ← Paint?
no getterinherited
textBaseline ← TextBaseline?
no getterinherited
textBg ← Color
no getterinherited
textCapitalization ↔ TextCapitalization?
getter/setter pairoverride
textDecoration ← TextDecoration?
no getterinherited
textDirection ↔ TextDirection?
getter/setter pairoverride
textInputAction ↔ TextInputAction?
getter/setter pairoverride
textKeyboard → void
no setterinherited
theme ← ThemeData
no getterinherited
tip ← String
no getterinherited
titleLarge ← BuildContext
no getterinherited
titleMedium ← BuildContext
no getterinherited
titleSmall ← BuildContext
no getterinherited
toolbarOptions ↔ ToolbarOptions?
getter/setter pair
tooltip ← String
no getterinherited
underline → void
no setterinherited
underlineText → void
no setterinherited
unspecifiedAction → void
no setterinherited
urlKeyboard → void
no setterinherited
validator ↔ FormFieldValidator<String>?
getter/setter pair
visible ← bool
no getterinherited
w ← double
no getterinherited
w100 → void
no setterinherited
w200 → void
no setterinherited
w300 → void
no setterinherited
w400 → void
no setterinherited
w500 → void
no setterinherited
w600 → void
no setterinherited
w700 → void
no setterinherited
w800 → void
no setterinherited
w900 → void
no setterinherited
wavy → void
no setterinherited
wFactor ← double
no getterinherited
wFull → void
no setterinherited
width ← double
no getterinherited
widthPercent ← double
no getterinherited
wMax ← double
no getterinherited
wMin ← double
no getterinherited
wordSpacing ← double?
no getterinherited
wPercent ← double
no getterinherited
wrap → dynamic
Cancel parent size inheritance by wrapping the widget with a Wrap.
no setterinherited

Methods

build(BuildContext _) → Widget
inherited
createElement() → StatelessElement
Creates a StatelessElement to manage this widget's location in the tree.
inherited
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
of(NikuTextFormField? v) → void
inherited
on({void tapDown(TapDownDetails)?, void tapUp(TapUpDetails)?, VoidCallback? tap, VoidCallback? tapCancel, VoidCallback? secondaryTap, void secondaryTapDown(TapDownDetails)?, void secondaryTapUp(TapUpDetails)?, VoidCallback? secondaryTapCancel, void tertiaryTapDown(TapDownDetails)?, void tertiaryTapUp(TapUpDetails)?, VoidCallback? tertiaryTapCancel, void doubleTapDown(TapDownDetails)?, VoidCallback? doubleTap, VoidCallback? doubleTapCancel, VoidCallback? longPress, void longPressStart(LongPressStartDetails)?, void longPressMoveUpdate(LongPressMoveUpdateDetails)?, VoidCallback? longPressUp, void longPressEnd(LongPressEndDetails)?, VoidCallback? secondaryLongPress, void secondaryLongPressStart(LongPressStartDetails)?, void secondaryLongPressMoveUpdate(LongPressMoveUpdateDetails)?, VoidCallback? secondaryLongPressUp, void secondaryLongPressEnd(LongPressEndDetails)?, void verticalDragDown(DragDownDetails)?, void verticalDragStart(DragStartDetails)?, void verticalDragUpdate(DragUpdateDetails)?, void verticalDragEnd(DragEndDetails)?, VoidCallback? verticalDragCancel, void horizontalDragDown(DragDownDetails)?, void horizontalDragStart(DragStartDetails)?, void horizontalDragUpdate(DragUpdateDetails)?, void horizontalDragEnd(DragEndDetails)?, VoidCallback? horizontalDragCancel, void forcePressStart(ForcePressDetails)?, void forcePressPeak(ForcePressDetails)?, void forcePressUpdate(ForcePressDetails)?, void forcePressEnd(ForcePressDetails)?, void panDown(DragDownDetails)?, void panStart(DragStartDetails)?, void panUpdate(DragUpdateDetails)?, void panEnd(DragEndDetails)?, VoidCallback? panCancel, void scaleStart(ScaleStartDetails)?, void scaleUpdate(ScaleUpdateDetails)?, void scaleEnd(ScaleEndDetails)?}) → void
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A short, textual description of this widget.
inherited
use(List<NikuTextFormField> v) → void
inherited
useAnimationBuilder({required Widget builder(BuildContext context, Widget child), required AnimationController animation}) → void
inherited
useBorder({InputBorder? all, InputBorder? base, InputBorder? enabled, InputBorder? disabled, InputBorder? focused, InputBorder? focusedError, InputBorder? error}) → void
inherited
useBorderColor({Color? all, Color? base, Color? enabled, Color? disabled, Color? focused, Color? focusedError, Color? error}) → void
inherited
useBorderWidth({double? all, double? base, double? enabled, double? disabled, double? focused, double? focusedError, double? error}) → void
inherited
useConstraints(_UseConstraints v) → void
inherited
useDarkMode(BuildContext context, NikuTextFormField builder(NikuTextFormField, bool)) → void
inherited
useDecoration(NikuInputDecoration v(NikuInputDecoration)) → void
inherited
useErrorStyle(_UseStyle v) → void
inherited
useFloatingLabelStyle(_UseStyle v) → void
inherited
useFocus(FocusNode builder(FocusNode?), {String? debugLabel, FocusOnKeyCallback? onKey, FocusOnKeyEventCallback? onKeyEvent, bool skipTraversal = false, bool canRequestFocus = true, bool descendantsAreFocusable = true}) → dynamic
inherited
useFocusNode(FocusNode builder(FocusNode?), {String? debugLabel, FocusOnKeyCallback? onKey, FocusOnKeyEventCallback? onKeyEvent, bool skipTraversal = false, bool canRequestFocus = true, bool descendantsAreFocusable = true}) → dynamic
inherited
useForm({Key? key, AutovalidateMode? autovalidateMode, Future<bool> onWillPop()?, void onChanged()?}) → void
inherited
useHelperStyle(_UseStyle v) → void
inherited
useHintStyle(_UseStyle v) → void
inherited
useLabelStyle(_UseStyle v) → void
inherited
useNikuBorder({NikuInputBorder? all, NikuInputBorder? base, NikuInputBorder? enabled, NikuInputBorder? disabled, NikuInputBorder? focused, NikuInputBorder? focusedError, NikuInputBorder? error}) → void
inherited
useParent(Widget compose(Niku)) → void
inherited
usePlatform(BuildContext context, {NikuTextFormField android(NikuTextFormField)?, NikuTextFormField iOS(NikuTextFormField)?, NikuTextFormField fuchsia(NikuTextFormField)?, NikuTextFormField linux(NikuTextFormField)?, NikuTextFormField macOS(NikuTextFormField)?, NikuTextFormField windows(NikuTextFormField)?, NikuTextFormField web(NikuTextFormField)?}) → void
inherited
usePrefixIconConstraints(_UseConstraints v) → void
inherited
usePrefixStyle(_UseStyle v) → void
inherited
useQuery(BuildContext context, NikuTextFormField builder(NikuTextFormField, MediaQueryData)) → void
inherited
useScreen(BuildContext context, {NikuTextFormField base(NikuTextFormField)?, NikuTextFormField xs(NikuTextFormField)?, NikuTextFormField sm(NikuTextFormField)?, NikuTextFormField md(NikuTextFormField)?, NikuTextFormField lg(NikuTextFormField)?, NikuTextFormField xl(NikuTextFormField)?}) → void
void useScreen({ // > 568px Widget Function(Niku)? base, // 568 - 640px Widget Function(Niku)? xs, // 640 - 768px Widget Function(Niku)? sm, // 768 - 920px Widget Function(Niku)? md, // 920 - 1024px Widget Function(Niku)? lg, // > 1024px Widget Function(Niku)? xl, })
inherited
useScrollView({ScrollController? controller, Axis scrollDirection = Axis.vertical, bool? primary, bool reverse = false, ScrollPhysics? physics, DragStartBehavior dragStartBehavior = DragStartBehavior.start, String? restorationId}) → void
inherited
useSize(BuildContext context, NikuTextFormField builder(NikuTextFormField, Size)) → void
inherited
useSturtStyle(NikuStrutStyle v(NikuStrutStyle)) → void
inherited
useSuffixIconConstraints(_UseConstraints v) → void
inherited
useSuffixStyle(_UseStyle v) → void
inherited
useTextStyle(NikuTextStyle v(NikuTextStyle)) → void
inherited
useThemeSelector(BuildContext context, {NikuTextFormField light(NikuTextFormField)?, NikuTextFormField dark(NikuTextFormField)?}) → void
inherited
widget(BuildContext context) → Widget
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited